==> qtjambi-scxml-6.5.3-sources.jar: io/qt/scxml/QScxmlDynamicScxmlServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates SCXML service instances from documents loaded at runtime</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmldynamicscxmlservicefactory.html">QScxmlDynamicScxmlServiceFactory</a></code></p>
 */
public class QScxmlDynamicScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlDynamicScxmlServiceFactory.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmldynamicscxmlservicefactory.html#QScxmlDynamicScxmlServiceFactory">QScxmlDynamicScxmlServiceFactory::<wbr>QScxmlDynamicScxmlServiceFactory(QScxmlExecutableContent::InvokeInfo,<wbr>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr>QObject*)</a></code></p>
     */
    public QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlDynamicScxmlServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlDynamicScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
}

==> qtjambi-scxml-6.6.2-sources.jar: io/qt/scxml/QScxmlDynamicScxmlServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates SCXML service instances from documents loaded at runtime</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmldynamicscxmlservicefactory.html">QScxmlDynamicScxmlServiceFactory</a></code></p>
 */
public class QScxmlDynamicScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlDynamicScxmlServiceFactory.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmldynamicscxmlservicefactory.html#QScxmlDynamicScxmlServiceFactory">QScxmlDynamicScxmlServiceFactory::<wbr/>QScxmlDynamicScxmlServiceFactory(QScxmlExecutableContent::InvokeInfo,<wbr/>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr/>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr/>QObject*)</a></code></p>
     */
    public QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlDynamicScxmlServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr/>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlDynamicScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlDynamicScxmlServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
}
